lru_memory_cache library
LRUCache is a Dart library that provides a least recently used (LRU) caching mechanism for in-memory data storage. It addresses the issues of unnecessary network requests and the persistence of stale data by efficiently managing the storage of frequently accessed items.
Classes
-
LRUMemoryCache<
K, V> - Holds cache data in memory for a set capacity Allows setting for a duration
-
ManyResult<
K, V> - Result of LRUMemoryCache.getMany Returns found and not found
Enums
- ExpireMode
- Option on how to remove expired items